#
# This script was written by David Kyger <david_kyger@symantec.com>
#
# See the Nessus Scripts License for details
#

if(description)
{
  script_id(12050);
  script_version ("$Revision: 1.1 $");
 script_bugtraq_id(5523);
  script_cve_id("CAN-2002-1417");

 name["english"] = "Novell Netbasic Scripting Server Directory Traversal";
 script_name(english:name["english"]);
 
 desc["english"] = "
Novell Netbasic Scripting Server Directory Traversal

It is possible to escape out of the root directory of the scripting server by 
substituting a forward or backward slash for %5C. As a result, sensitive 
information, such as environment and user information, could be obtained from 
the Netware server.

Example: http://server/nsn/..%5Cutil/userlist.bas

Solution : Apply the relevant patch
Risk Factor : Medium";


 script_description(english:desc["english"]);
 
 summary["english"] = "Checks for Novell Netbasic Scripting Server Directory Traversal Vulnerability";
 
 script_summary(english:summary["english"]);
 
 script_category(ACT_GATHER_INFO);
 script_copyright(english:"This script is Copyright (C) 2004 David Kyger");
 family["english"] = "Netware";
 script_family(english:family["english"]);
 script_dependencie("find_service.nes", "http_version.nasl");
 script_require_ports("Services/www", 80);
 exit(0);
}

#
# The script code starts here
#
include("http_func.inc");
include("http_keepalive.inc");

function check(req)
{
 soc = http_open_socket(port);
 if(soc)
 {
 req = http_get(item:req, port:port);
 send(socket:soc, data:req);
 r = http_recv(socket:soc);
 http_close_socket(soc);
 pattern = "Error running script";
 pattern2 = "Module load Failed";

 if((pattern >!< r) && (pattern2 >!< r)) {
        return(1);
        }
 }
 return(0);
}

flag = 0;

warning = string("
It is possible to escape out of the root directory of the scripting server by substituting 
a forward or backward slash for %5C. As a result, sensitive information, such as environment and user information, could be obtained from the Netware server.

The following Novell scripts can be executed on the server:");

port = get_kb_item("Services/www");
if(!port)port=80;
if(get_port_state(port)) {

	fl[0] = "nsn/..%5Cutil/chkvol.bas";
	fl[1] = "nsn/..%5Cutil/attrib.bas";
	fl[2] = "nsn/..%5Cutil/copy.bas";
	fl[3] = "nsn/..%5Cutil/del.bas";
	fl[4] = "nsn/..%5Cutil/dir.bas";
	fl[5] = "nsn/..%5Cutil/glist.bas";
	fl[6] = "nsn/..%5Cutil/lancard.bas";
	fl[7] = "nsn/..%5Cutil/md.bas";
	fl[8] = "nsn/..%5Cutil/rd.bas";
	fl[9] = "nsn/..%5Cutil/ren.bas";
	fl[10] = "nsn/..%5Cutil/send.bas";
	fl[11] = "nsn/..%5Cutil/set.bas";
	fl[12] = "nsn/..%5Cutil/slist.bas";
	fl[13] = "nsn/..%5Cutil/type.bas";
	fl[14] = "nsn/..%5Cutil/userlist.bas";
	fl[15] = "nsn/..%5Cweb/env.bas";
	fl[16] = "nsn/..%5Cweb/fdir.bas";
	fl[17] = "nsn/..%5Cwebdemo/env.bas";
	fl[18] = "nsn/..%5Cwebdemo/fdir.bas"; 

   for(i=0;fl[i];i=i+1) 
   { 
    url = string(fl[i]);
    if(is_cgi_installed_ka(item:fl[i], port:port)) 
	{
        if(check(req:url)) {
        warning = warning + string("\n", fl[i]); 
        flag = 1;
        }
    }
   }
    if (flag > 0) {
	warning += string("\n\nSolution : Apply the relevant patch\n\n");
        warning += string("Risk Factor : Medium");
        security_warning(port:port, data:warning);
        } else {
          exit(0);
    }
}


